#-----------------------------------------------------------------
# pynut
#-----------------------------------------------------------------
def nutOther():
    try:
        from pyNutTools import nutOther
    except Exception as err:
        print('  IMPORT FAIL |nutOther|, err:|{}|'.format(err))
        return None
    return nutOther

def nutDataframe():
    try:
        from pyNutTools import nutDataframe
    except Exception as err:
        print('  IMPORT FAIL |nutDataframe|, err:|{}|'.format(err))
        return None
    return nutDataframe

def nutDate():
    try:
        from pyNutTools import nutDate
    except Exception as err:
        print('  IMPORT FAIL |nutDate|, err:|{}|'.format(err))
        return None
    return nutDate


#-----------------------------------------------------------------
# Generic Lib
#-----------------------------------------------------------------
def logging():
    try:    import logging
    except Exception as err:
        print('  IMPORT FAIL |logging|, err:|{}|'.format(err))
        return None
    return logging

def logger():
    try:
        import logging
        logger = logging.getLogger()
    except Exception as err:
        print('  IMPORT FAIL |logger|, err:|{}|'.format(err))
        return None
    return logger


#-----------------------------------------------------------------
# dataframe
#-----------------------------------------------------------------
def pandas():
    try:    import pandas
    except Exception as err:
        print('  IMPORT FAIL |pandas|, err:|{}|'.format(err))
        return None
    return pandas


#-----------------------------------------------------------------
# Files
#-----------------------------------------------------------------
def shutil():
    try:    import shutil
    except Exception as err:
        print('  IMPORT FAIL |shutil|, err:|{}|'.format(err))
        return None
    return shutil

def psutil():
    try:    import psutil
    except Exception as err:
        print('  IMPORT FAIL |psutil|, err:|{}|'.format(err))
        return None
    return psutil

def glob():
    try:    import glob
    except Exception as err:
        print('  IMPORT FAIL |glob|, err:|{}|'.format(err))
        return None
    return glob

def csv():
    try:    import csv
    except Exception as err:
        print('  IMPORT FAIL |csv|, err:|{}|'.format(err))
        return None
    return csv

def copy():
    try:    import copy
    except Exception as err:
        print('  IMPORT FAIL |copy|, err:|{}|'.format(err))
        return None
    return copy

def pythoncom():
    try:    import pythoncom
    except Exception as err:
        print('  IMPORT FAIL |pythoncom|, err:|{}|'.format(err))
        return None
    return pythoncom

def win32():
    try:    import win32com.client as win32
    except Exception as err:
        print('  IMPORT FAIL |win32|, err:|{}|'.format(err))
        return None
    return win32

def ZipFile():
    try:    from zipfile import ZipFile
    except Exception as err:
        print('  IMPORT FAIL |ZipFile|, err:|{}|'.format(err))
        return None
    return ZipFile

def xlwings():
    try:    import xlwings
    except Exception as err:
        print('  IMPORT FAIL |xlwings|, err:|{}|'.format(err))
        return None
    return xlwings

def xlsxwriter():
    try:    import xlsxwriter
    except Exception as err:
        print('  IMPORT FAIL |xlsxwriter|, err:|{}|'.format(err))
        return None
    return xlsxwriter

def xlrd():
    try:    import xlrd
    except Exception as err:
        print('  IMPORT FAIL |xlrd|, err:|{}|'.format(err))
        return None
    return xlrd

def openpyxl():
    try:    import openpyxl
    except Exception as err:
        print('  IMPORT FAIL |openpyxl|, err:|{}|'.format(err))
        return None
    return openpyxl

def openpyxl_styles():
    try:    import openpyxl.styles as openpyxl_styles
    except Exception as err:
        print('  IMPORT FAIL |openpyxl_styles|, err:|{}|'.format(err))
        return None
    return openpyxl_styles

def openpyxl_Excel():
    try:    import openpyxl.reader.excel as openpyxl_Excel
    except Exception as err:
        print('  IMPORT FAIL |openpyxl_Excel|, err:|{}|'.format(err))
        return None
    return openpyxl_Excel

def PageSetupProperties():
    try:    from openpyxl.worksheet.properties import PageSetupProperties
    except Exception as err:
        print('  IMPORT FAIL |PageSetupProperties|, err:|{}|'.format(err))
        return None
    return PageSetupProperties

def NamedStyle():
    try:    from openpyxl.styles import NamedStyle
    except Exception as err:
        print('  IMPORT FAIL |NamedStyle|, err:|{}|'.format(err))
        return None
    return NamedStyle

def Font():
    try:    from openpyxl.styles import Font
    except Exception as err:
        print('  IMPORT FAIL |Font|, err:|{}|'.format(err))
        return None
    return Font

def PatternFill():
    try:    from openpyxl.styles import PatternFill
    except Exception as err:
        print('  IMPORT FAIL |PatternFill|, err:|{}|'.format(err))
        return None
    return PatternFill

def colors():
    try:    from openpyxl.styles import colors
    except Exception as err:
        print('  IMPORT FAIL |colors|, err:|{}|'.format(err))
        return None
    return colors

def Border():
    try:    from openpyxl.styles import Border
    except Exception as err:
        print('  IMPORT FAIL |Border|, err:|{}|'.format(err))
        return None
    return Border

def Side():
    try:    from openpyxl.styles import Side    # , Alignment, Color
    except Exception as err:
        print('  IMPORT FAIL |Side|, err:|{}|'.format(err))
        return None
    return Side



import os
import datetime
import pytest
try:
    import nutFiles as fl
except:
    print('Online Test...')
    from pyNut import nutFiles as fl


#=============================================================================
# UNIT TEST
#=============================================================================
def test_fStr_myFileName():
    fileName_os =   os.path.basename(__file__)
    fileName =      fl.fStr_myFileName(__file__)
    assert (fileName_os == fileName)
def test_fStr_myPath():
    path_os =       os.path.dirname(os.path.abspath(__file__))
    myPath =        fl.fStr_myPath(__file__)
    assert (path_os == myPath)
def test_fStr_GetEnvUserName():
    EnvUserName =   fl.fStr_GetEnvUserName()
    EnvUserName_os = os.environ['USERPROFILE']
    assert (EnvUserName == EnvUserName_os)
def test_fStr_GetFolderFromPath():
    myPath =        fl.fStr_myPath(__file__) + '\\' + fl.fStr_myFileName(__file__)
    folder =        fl.fStr_GetFolderFromPath(myPath)
    str_folder =    fl.fStr_myPath(__file__)
    assert (folder == str_folder)
def test_fStr_GetFileFromPath():
    myPath =        fl.fStr_myPath(__file__) + '\\' + fl.fStr_myFileName(__file__)
    myFileName =    fl.fStr_GetFileFromPath(myPath)
    str_fileName =  fl.fStr_myFileName(__file__)
    assert (myFileName == str_fileName)
def test_fStr_BuildPath():
    myPath =        fl.fStr_myPath(__file__) + '\\' + fl.fStr_myFileName(__file__)
    folder =        fl.fStr_myPath(__file__)
    myFileName =    fl.fStr_myFileName(__file__)
    Path_0 =        fl.fStr_BuildPath(folder, myFileName)
    Path_1 =        fl.fStr_BuildPath(myPath, '')
    Path_2 =        fl.fStr_BuildPath('', myPath)
    assert (Path_0 == Path_1)
    assert (Path_0 == Path_2)

def test_fL_listFile():
    myFolder =  fl.fStr_myPath(__file__)
    fileName =  fl.fStr_myFileName(__file__)
    l_files =   fl.fL_listFile(myFolder)
    l_files = [fl.fStr_GetFileFromPath(path) for path in l_files]
    assert (fileName in l_files)

@pytest.mark.parametrize("fileName, expectedReturn, bl_exactNumb",
                         [('file_{*}_1.zip', 'file_*_1.zip', False),
                          ('file_{XXXX}.zip', 'file_????.zip', True),
                          ('file_{XXXX}.zip', 'file_*.zip', False)])
def test_fStr_TransformFilName_fromXXX_forGlobFunction(fileName, expectedReturn, bl_exactNumb):
    str_newName = fl.fStr_TransformFilName_fromXXX_forGlobFunction(fileName, bl_exactNumberX = bl_exactNumb)
    assert str_newName == expectedReturn

@pytest.mark.parametrize("fileName_X, bl_searchOnly, bl_exactNb, exp_fileName",
                         [('test_{XXX}Files.py', False, True, None),
                          ('test_{XX}Files.py', False, False, None),
                          ('test_{XX}Files.py', False, True, None),
                          ('test_{*}Files.py', False, True, None),
                          ('test_{X}Files.py', False, True, None),
                          ('abc_{XXX}_abc.py', True, None, 'abc_{XXX}_abc.py')
                          ])
def test_fL_GetFileListInFolder(fileName_X, bl_searchOnly, bl_exactNb, exp_fileName):
    myFolder =  fl.fStr_myPath(__file__)
    if exp_fileName is None:    fileName = fl.fStr_myFileName(__file__)
    else:                       fileName = exp_fileName
    L_filIn =   fl.fL_GetFileListInFolder(myFolder, fileName_X, bl_searchOnly, bl_exactNb)
    L_filIn = [fl.fStr_GetFileFromPath(path) for path in L_filIn]
    assert (fileName in L_filIn)

@pytest.mark.parametrize("fileName_X, bl_searchOnly, bl_exactNb",
                         [('abc_{XXX}_abc.py', False, True),
                          ('abc_{XXX}_abc.py', False, False)])
def test_FAIL_fL_GetFileListInFolder(fileName_X, bl_searchOnly, bl_exactNb):
    myFolder =  fl.fStr_myPath(__file__)
    with pytest.raises(Exception):
        fl.fL_GetFileListInFolder(myFolder, fileName_X, bl_searchOnly, bl_exactNb)

@pytest.mark.parametrize("fileName_X, bl_searchOnly, bl_exactNb, exp_fileName",
                         [('test_{XXX}Files.py', False, True, None),
                          ('test_{XX}Files.py', False, False, None),
                          ('test_{XX}Files.py', False, True, None),
                          ('test_{*}Files.py', False, True, None),
                          ('test_{X}Files.py', False, True, None),
                          ('abc_{XXX}_abc.py', True, None, 'abc_{XXX}_abc.py')
                          ])
def test_fStr_GetMostRecentFile_InFolder(fileName_X, bl_searchOnly, bl_exactNb, exp_fileName):
    myFolder =  fl.fStr_myPath(__file__)
    if exp_fileName is None:    fileName = fl.fStr_myFileName(__file__)
    else:                       fileName = exp_fileName
    str_fileName =  fl.fStr_GetMostRecentFile_InFolder(myFolder, fileName_X, bl_searchOnly, bl_exactNb)
    assert (fileName == str_fileName)

@pytest.mark.parametrize("fileName_X, bl_searchOnly, bl_exactNb",
                         [('abc_{XXX}_abc.py', False, True),
                          ('abc_{XXX}_abc.py', False, False)])
def test_FAIL_fStr_GetMostRecentFile_InFolder(fileName_X, bl_searchOnly, bl_exactNb):
    myFolder =  fl.fStr_myPath(__file__)
    with pytest.raises(Exception):
        fl.fStr_GetMostRecentFile_InFolder(myFolder, fileName_X, bl_searchOnly, bl_exactNb)


@pytest.mark.parametrize("fileName_X",
                         [('test_nutFiles.py'), ('_nutFiles.py'),
                          ('test_{XXX}Files.py'), ('test_{XX}Files.py'), ('test_{X}Files.py'),
                          ('test_{*}Files.py')])
def test_fL_GetFileList_withinModel(fileName_X):
    myFolder =  fl.fStr_myPath(__file__)
    fileName =  fl.fStr_myFileName(__file__)
    l_files =   fl.fL_listFile(myFolder)
    l_files_X = fl.fL_GetFileList_withinModel(l_files, fileName_X)
    l_files_X = [fl.fStr_GetFileFromPath(path) for path in l_files_X]
    assert (fileName in l_files_X)
    assert (len(l_files_X) == 1)

@pytest.mark.parametrize("fileName_X", [('test_{XXXFiles.py')])
def test_fL_GetFileList_withinModel_2(fileName_X):
    myFolder =  fl.fStr_myPath(__file__)
    fileName =  fl.fStr_myFileName(__file__)
    l_files =   fl.fL_listFile(myFolder)
    l_files_X = fl.fL_GetFileList_withinModel(l_files, fileName_X)
    l_files_X = [fl.fStr_GetFileFromPath(path) for path in l_files_X]
    assert (fileName in l_files_X)

@pytest.mark.parametrize("fileName_X", [('abc_{XXX}_abc.py')])
def test_fL_GetFileList_withinModel_empty(fileName_X):
    myFolder = fl.fStr_myPath(__file__)
    l_files = fl.fL_listFile(myFolder)
    l_files_X = fl.fL_GetFileList_withinModel(l_files, fileName_X)
    assert (len(l_files_X) == 0)

def test_fDte_GetModificationDate():
    myPath = fl.fStr_myPath(__file__) + '\\' + fl.fStr_myFileName(__file__)
    dte_modif = fl.fDte_GetModificationDate(myPath)
    assert (isinstance(dte_modif, datetime.datetime))


def test_fL_KeepFiles_wTimeLimit():
    myFolder = fl.fStr_myPath(__file__)
    l_files = fl.fL_listFile(myFolder)
    l_pathReturn = fl.fL_KeepFiles_wTimeLimit(l_files, dte_after = 100_000)
    assert (isinstance(l_pathReturn, list))
    assert(len(l_pathReturn) > 0)
    l_pathEmpty = fl.fL_KeepFiles_wTimeLimit(l_files, dte_after=-1)
    # print('l_pathEmpty', l_pathEmpty)
    # print(len(l_pathEmpty))
    assert (isinstance(l_pathEmpty, list))
    assert (l_pathEmpty == [])

def test_fBl_createDir():
    myFolder = fl.fStr_myPath(__file__)
    bl_creation = fl.fBl_createDir(myFolder)
    assert (bl_creation is False)
    # We wont create a folder for a Unit Test

def test_fBl_fileTooOld():
    myPath = fl.fStr_myPath(__file__) + '\\' + fl.fStr_myFileName(__file__)
    bl_tooOld = fl.fBl_fileTooOld(myPath, int_dayHisto=100_000)
    assert (bl_tooOld is False)
    bl_tooOld = fl.fBl_fileTooOld(myPath, int_dayHisto=-1)
    assert (bl_tooOld is True)
    myPath_noFile = fl.fStr_myPath(__file__) + '\\aaabbbccc.csv'
    bl_tooOld = fl.fBl_fileTooOld(myPath_noFile, int_dayHisto=-1)
    assert (bl_tooOld is False)



import pathlib
from setuptools import setup, find_packages
import pyNutFiles

# The text of the README file
ME_PATH = pathlib.Path(__file__).parent
README = (ME_PATH / "README.md").read_text()

# This call to setup() does all the work
setup(
    name    = "pynut-Files",
    version = pyNutFiles.__version__,
    description = "Function easing life :)",
    long_description = README,
    long_description_content_type = "text/markdown",
    url = "https://github.com/Laurent-Tupin/pynut_Files",
    author = "Laurent Tupin",
    author_email = "laurent.tupinn@gmail.com",
    license = "Copyright 2022-2035",
    classifiers=[
        "License :: Free For Home Use",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
    ],
    packages = find_packages(exclude = ("test",)),
    include_package_data = True,
    install_requires = ["pynut-tools==2.1.8", "openpyxl==3.0.5", "psutil==5.9.0",
                        "pywin32==303", "xlrd==1.2.0", "XlsxWriter==1.3.5",
                        "xlwings==0.20.8"]
    #entry_points={"console_scripts": ["EXEnameFile=FolderName.__main__:main"]},
)
